pub struct CommLayerData { /* private fields */ }Expand description
The CommLayerData has shared ownership of the root SubCommData.
Implementations
Sourceimpl CommLayerData
impl CommLayerData
Sourcepub fn comm_data(&self) -> SubCommData
pub fn comm_data(&self) -> SubCommData
Returns a clone of the root SubCommData at this moment.
Sourcepub fn reset(&self) -> SubCommData
pub fn reset(&self) -> SubCommData
Resets the root SubCommData and returns it.
Do not use this method while an instrumented target = cryprot_metrics
span is active, as this will result in inconsistent data.